@@ -383,6 +383,20 @@ public:
 			{counter = value;};
 	};
 
+	/**
+	 * Grouping option.  This is used to create a grouping entry in
+	 * the shell::help() listing.
+	 * @author David Sugar <dyfet@gnutelephony.org>
+	 */
+	class __EXPORT groupopt : public Option
+	{
+	private:
+		virtual const char *assign(const char *value);
+
+	public:
+		groupopt(const char *help);
+	};
+
 	/**
 	 * Text option for shell parsing.  This offers a quick-use class
 	 * to parse a shell flag, along with a numberic text that may be
